@@ -5,7 +5,7 @@
  *			  routines for enforce plans for every expr/query and
  *			  related checks over these plans.
  *
- * by Pavel Stehule 2013-2023
+ * by Pavel Stehule 2013-2024
  *
  *-------------------------------------------------------------------------
  */
@@ -1179,7 +1179,7 @@ free_string_constant(PLpgSQL_checkstate *cstate, PLpgSQL_row *row)
 			cstate->strconstvars[varno] = NULL;
 		}
 
-		field = cstate->estate->datums[fnum];
+		field = cstate->estate->datums[varno];
 
 		if (field->dtype == PLPGSQL_DTYPE_ROW)
 			free_string_constant(cstate, (PLpgSQL_row *) field);
